emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/eev e80c5efd00 1/2: Fixed a bug in `find-pdftools-page'


From: ELPA Syncer
Subject: [elpa] externals/eev e80c5efd00 1/2: Fixed a bug in `find-pdftools-page'.
Date: Sat, 15 Oct 2022 18:57:35 -0400 (EDT)

branch: externals/eev
commit e80c5efd00214613e6837fa11036bf8463040529
Author: Eduardo Ochs <eduardoochs@gmail.com>
Commit: Eduardo Ochs <eduardoochs@gmail.com>

    Fixed a bug in `find-pdftools-page'.
---
 ChangeLog      |  7 +++++++
 VERSION        |  4 ++--
 eev-kla.el     |  5 +++--
 eev-pdflike.el | 22 +++++++++++++++-------
 eev-rstdoc.el  | 10 ++++++++--
 eev.el         |  2 +-
 6 files changed, 36 insertions(+), 14 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index 173aedb745..43536740ab 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,10 @@
+2022-10-15  Eduardo Ochs  <eduardoochs@gmail.com>
+
+       * eev-pdflike.el (find-pdftools-page, find-xpdf-page)
+       (find-pdftoolsr-page): added an (interactive ...).
+       (ee-code-pdftextbackend, ee-code-pdfbackend): same.
+       (find-pdftools-page): use `revert-without-query'.
+
 2022-09-25  Eduardo Ochs  <eduardoochs@gmail.com>
 
        * eev-kla.el (ee-preferred-c-guess): new variable.
diff --git a/VERSION b/VERSION
index b191f7daa2..7923a84029 100644
--- a/VERSION
+++ b/VERSION
@@ -1,2 +1,2 @@
-Mon Sep 26 03:47:41 GMT 2022
-Mon Sep 26 00:47:41 -03 2022
+Sat Oct 15 22:22:51 GMT 2022
+Sat Oct 15 19:22:51 -03 2022
diff --git a/eev-kla.el b/eev-kla.el
index 285ede6817..bea54e4711 100644
--- a/eev-kla.el
+++ b/eev-kla.el
@@ -28,6 +28,7 @@
 ;;                 <http://angg.twu.net/eev-intros/find-eev-intro.html>
 ;;                                                (find-eev-intro)
 
+;; «.prerequisites»            (to "prerequisites")
 ;; «.intro»                    (to "intro")
 ;;  «.test»                    (to "test")
 ;;
@@ -50,8 +51,7 @@
 
 ;;; Commentary:
 
-;; «intro»  (to ".intro")
-;;
+;;   «prerequisites»  (to ".prerequisites")
 ;; 0. Prerequisites
 ;; ================
 ;; This tool will only make sense to people who understand anchors,
@@ -66,6 +66,7 @@
 ;;
 ;;
 ;;
+;;   «intro»  (to ".intro")
 ;; 1. Very short introduction
 ;; ==========================
 ;; This:
diff --git a/eev-rstdoc.el b/eev-rstdoc.el
index 3212411965..031b71b234 100644
--- a/eev-rstdoc.el
+++ b/eev-rstdoc.el
@@ -19,7 +19,7 @@
 ;;
 ;; Author:     Eduardo Ochs <eduardoochs@gmail.com>
 ;; Maintainer: Eduardo Ochs <eduardoochs@gmail.com>
-;; Version:    20220828
+;; Version:    20221009
 ;; Keywords:   e-scripts
 ;;
 ;; Latest version: <http://angg.twu.net/eev-current/eev-rstdoc.el>
@@ -44,7 +44,12 @@
 ;; 0. Warning
 ;; ==========
 ;; This is an experimental feature.
-;; See these posts in the mailing list:
+;; I'm still cleaning it up, and I'll give a presentation
+;; about it in the EmacsConf2022:
+;;
+;;   http://angg.twu.net/emacsconf2022-py.html
+;;
+;; See also these posts in the mailing list:
 ;;
 ;;   https://lists.gnu.org/archive/html/eev/
 ;;   https://lists.gnu.org/archive/html/eev/2022-08/threads.html
@@ -424,6 +429,7 @@
 ;;      (find-eev \"eev-rstdoc.el\" \"code-rstdoc\")
 ;;
 ;; Tests: (find-eppp {var})
+;;        (code-rstdoc {kw})
 ;;        (find-{c}doc-expand  \"{base}\")
 ;;        (find-{c}docw-expand \"{base}\")
 ;;        (find-{c}docr-expand \"{base}\")
diff --git a/eev.el b/eev.el
index c41797d298..ed95725dfe 100644
--- a/eev.el
+++ b/eev.el
@@ -6,7 +6,7 @@
 ;; Package-Requires: ((emacs "24.4"))
 ;; Keywords: lisp e-scripts
 ;; URL: http://angg.twu.net/#eev
-;; Version: 20220926
+;; Version: 20221015
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/eev-pdflike.el b/eev-pdflike.el
index d7dcede3e0..4ad964953a 100644
--- a/eev-pdflike.el
+++ b/eev-pdflike.el
@@ -19,7 +19,7 @@
 ;;
 ;; Author:     Eduardo Ochs <eduardoochs@gmail.com>
 ;; Maintainer: Eduardo Ochs <eduardoochs@gmail.com>
-;; Version:    20220404
+;; Version:    20221015
 ;; Keywords:   e-scripts
 ;;
 ;; Latest version: <http://angg.twu.net/eev-current/eev-pdflike.el>
@@ -180,6 +180,7 @@
 ;; «.find-pdftotext-text»              (to "find-pdftotext-text")
 ;; «.find-texworkspdf-page»            (to "find-texworkspdf-page")
 ;; «.find-pdftools-page»               (to "find-pdftools-page")
+;; «.find-pdftoolsr-page»              (to "find-pdftoolsr-page")
 ;; «.find-xdvi-page»                   (to "find-xdvi-page")
 ;; «.find-djview-page»                 (to "find-djview-page")
 ;; «.find-evince-page»                 (to "find-evince-page")
@@ -310,6 +311,7 @@ newline are spurious - and replaces them by \"(ff)\"."
 ;; (find-eevgrep \"grep --color=auto -nH -e '\\\"{pdfbackend}\\\"' 
eev-pdflike.el\")
 ;;
 \(defun      find-{pdfbackend} (fname &optional page &rest rest)
+  (interactive \"fPDF file: \")
   (find-bgprocess (ee-find-{pdfbackend} fname page)))
 
 ;; (find-code-{pdfbackend} \"C\" \"FNAME\")
@@ -328,7 +330,7 @@ newline are spurious - and replaces them by \"(ff)\"."
   ;;
   (setq ee-pdflike-last 'find-{<}c{>}page)
   (defun find-{<}c{>}page (&optional page &rest rest)
-    (interactive)
+    (interactive \\\"fPDF file: \\\")
     (setq ee-pdflike-last 'find-{<}c{>}page)
     (find-{pdfbackend} {<}(ee-pp0 fname){>} page))
   \"))
@@ -387,7 +389,7 @@ newline are spurious - and replaces them by \"(ff)\"."
   (setq ee-page-fname  {<}(ee-pp0 fname){>})
   (setq ee-page-offset {<}(ee-pp0 offset){>})
   (defun find-{<}c{>}text (&optional page &rest rest)
-    (interactive)
+    (interactive \\\"fPDF file: \\\")
     (setq ee-page-c      {<}(ee-pp0 c){>})
     (setq ee-page-fname  {<}(ee-pp0 fname){>})
     (setq ee-page-offset {<}(ee-pp0 offset){>})
@@ -671,6 +673,7 @@ version just returns the value of the variable
 (defun find-xpdf-page (fname &optional page &rest rest)
   "This defun will be overridden by the `code-pdfbackend' below.
 We define it just to make this work: (find-efunction 'find-xpdf-page)"
+  (interactive "fPDF file: ")
   (find-bgprocess (ee-find-xpdf-page fname page)))
 
 ;; (find-code-pdfbackend "xpdf-page")
@@ -780,6 +783,7 @@ We define it just to make this work: (find-efunction 
'find-pdftotext-page)"
   "Open PDFFILE in the current window using pdf-tools.
 If PAGE is given, go to that page; if PAGE is nil, stay in the
 current page."
+  (interactive "fPDF file: ")
   ;;
   ;; `pdf-loader-install' makes sure that pdf-tools is loaded and
   ;; that it has set up `auto-mode-alist' and `magic-mode-alist' to
@@ -793,14 +797,18 @@ current page."
   ;;
   ;; Old way: (pdf-tools-install)
   (pdf-loader-install)
-  ;; Open pdffile. You will get weird results if it is not a PDF.
-  (find-fline pdffile)
-  ;; Reload the PDF if it has changed.
+  ;;
+  ;; Open PDFFILE. You will get weird results if it is not a PDF.
+  ;; Use two tricks with "revert" to reload the PDF if it has changed.
+  (let ((revert-without-query '(".*")))
+    (find-fline pdffile))
   (revert-buffer nil 'noconfirm)
+  ;;
   ;; If PAGE is given, go to that page.
   (if page (pdf-view-goto-page page)))
 
 
+;; «find-pdftoolsr-page»  (to ".find-pdftoolsr-page")
 ;; Test:
 ;;   (defalias 'find-pdf-page 'find-xpdf-page)
 ;;   (defalias 'find-pdf-page 'find-pdftoolsr-page)
@@ -808,7 +816,7 @@ current page."
 ;;   (find-pdf-page "~/Coetzee99.pdf" 3)
 (defun find-pdftoolsr-page (fname &optional page &rest rest)
   "Like `find-pdftools-page', but opens the PDF in the right window."
-  (interactive)
+  (interactive "fPDF file: ")
   (find-2a nil '(find-pdftools-page fname page)))
 
 